==> constructorio-ui-quizzes-1.4.5.tgz: package/lib/mjs/components/CioQuiz/index.js <==
import React, { useEffect, useState } from 'react';
import QuizContext from './context';
import QuizQuestions from '../QuizQuestions';
import ResultContainer from '../ResultContainer/ResultContainer';
import { RequestStates } from '../../constants';
import Spinner from '../Spinner/Spinner';
import useQuiz from '../../hooks/useQuiz';
import SessionPromptModal from '../SessionPromptModal/SessionPromptModal';
import { convertPrimaryColorsToString } from '../../utils';
export default function CioQuiz(props) {
    const { cioClient, state, events: { hydrateQuiz, hasSessionStorageState, resetSessionStorageState }, getAddToCartButtonProps, getCoverQuestionProps, getHydrateQuizButtonProps, getNextQuestionButtonProps, getOpenTextInputProps, getPreviousQuestionButtonProps, getQuizImageProps, getQuizResultButtonProps, getQuizResultLinkProps, getResetQuizButtonProps, getSelectInputProps, primaryColorStyles, } = useQuiz(props);
    const [showSessionPrompt, setShowSessionPrompt] = useState(false);
    const { resultsPageOptions, sessionStateOptions } = props;
    useEffect(() => {
        // Respect showSessionModal if defined, else default to true.
        if (sessionStateOptions?.showSessionModal !== undefined) {
            setShowSessionPrompt(sessionStateOptions?.showSessionModal &&
                hasSessionStorageState() &&
                !state.quiz.skipToResults);
        }
        else {
            setShowSessionPrompt(hasSessionStorageState() && !state.quiz.skipToResults);
        }
        if (state.quiz.skipToResults)
            hydrateQuiz();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    const contextValue = {
        cioClient,
        state,
        getAddToCartButtonProps,
        getCoverQuestionProps,
        getHydrateQuizButtonProps,
        getNextQuestionButtonProps,
        getOpenTextInputProps,
        getPreviousQuestionButtonProps,
        getQuizImageProps,
        getQuizResultButtonProps,
        getQuizResultLinkProps,
        getResetQuizButtonProps,
        getSelectInputProps,
        customClickItemCallback: !!resultsPageOptions?.onQuizResultClick,
        primaryColorStyles,
    };
    if (state.quiz.requestState === RequestStates.Loading) {
        return (React.createElement("div", { className: 'cio-quiz' },
            React.createElement(Spinner, null)));
    }
    if (state.quiz.requestState === RequestStates.Success) {
        return (React.createElement("div", { className: 'cio-quiz' },
            React.createElement("style", null,
                ".cio-quiz ",
                convertPrimaryColorsToString(primaryColorStyles)),
            React.createElement(SessionPromptModal, { resetStoredState: resetSessionStorageState, continueSession: hydrateQuiz, showSessionPrompt: showSessionPrompt, setShowSessionPrompt: setShowSessionPrompt }),
            React.createElement(QuizContext.Provider, { value: contextValue }, state.quiz.results || state.quiz.skipToResults ? (React.createElement(ResultContainer, { options: resultsPageOptions })) : (state.quiz.currentQuestion && React.createElement(QuizQuestions, null)))));
    }
    return null;
}

==> constructorio-ui-quizzes-1.5.0.tgz: package/lib/mjs/components/CioQuiz/index.js <==
import React, { useEffect, useState } from 'react';
import QuizContext from './context';
import QuizQuestions from '../QuizQuestions';
import ResultContainer from '../ResultContainer/ResultContainer';
import ControlBar from '../ControlBar/ControlBar';
import { RequestStates } from '../../constants';
import Spinner from '../Spinner/Spinner';
import useQuiz from '../../hooks/useQuiz';
import SessionPromptModal from '../SessionPromptModal/SessionPromptModal';
import { convertPrimaryColorsToString, renderImages } from '../../utils';
export default function CioQuiz(props) {
    const { cioClient, state, events: { hydrateQuiz, hasSessionStorageState, resetSessionStorageState }, getAddToCartButtonProps, getCoverQuestionProps, getHydrateQuizButtonProps, getNextQuestionButtonProps, getOpenTextInputProps, getPreviousQuestionButtonProps, getQuizImageProps, getQuizResultButtonProps, getQuizResultLinkProps, getResetQuizButtonProps, getSelectInputProps, primaryColorStyles, } = useQuiz(props);
    const [showSessionPrompt, setShowSessionPrompt] = useState(false);
    const { resultsPageOptions, sessionStateOptions } = props;
    useEffect(() => {
        // Respect showSessionModal if defined, else default to true.
        if (sessionStateOptions?.showSessionModal !== undefined) {
            setShowSessionPrompt(sessionStateOptions?.showSessionModal &&
                hasSessionStorageState() &&
                !state.quiz.skipToResults);
        }
        else {
            setShowSessionPrompt(hasSessionStorageState() && !state.quiz.skipToResults);
        }
        if (state.quiz.skipToResults)
            hydrateQuiz();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    const contextValue = {
        cioClient,
        state,
        getAddToCartButtonProps,
        getCoverQuestionProps,
        getHydrateQuizButtonProps,
        getNextQuestionButtonProps,
        getOpenTextInputProps,
        getPreviousQuestionButtonProps,
        getQuizImageProps,
        getQuizResultButtonProps,
        getQuizResultLinkProps,
        getResetQuizButtonProps,
        getSelectInputProps,
        customClickItemCallback: !!resultsPageOptions?.onQuizResultClick,
        primaryColorStyles,
    };
    if (state.quiz.requestState === RequestStates.Loading) {
        return (React.createElement("div", { className: 'cio-quiz cio-quiz-loading' },
            React.createElement(Spinner, null)));
    }
    const questionData = state.quiz.currentQuestion?.next_question;
    const questionType = questionData?.type;
    const questionImages = questionData?.images;
    const displayBackgroundImage = (questionType === 'single' || questionType === 'multiple') && questionImages;
    if (state.quiz.requestState === RequestStates.Success) {
        return (React.createElement("div", { className: 'cio-quiz' },
            displayBackgroundImage && renderImages(questionImages, 'cio-question-background-image'),
            React.createElement("style", null,
                ".cio-quiz ",
                convertPrimaryColorsToString(primaryColorStyles)),
            React.createElement(SessionPromptModal, { resetStoredState: resetSessionStorageState, continueSession: hydrateQuiz, showSessionPrompt: showSessionPrompt, setShowSessionPrompt: setShowSessionPrompt }),
            React.createElement(QuizContext.Provider, { value: contextValue }, state.quiz.results || state.quiz.skipToResults ? (React.createElement(ResultContainer, { options: resultsPageOptions })) : (state.quiz.currentQuestion && (React.createElement(React.Fragment, null,
                React.createElement(QuizQuestions, null),
                React.createElement(ControlBar, { ctaButtonText: questionData?.cta_text || undefined })))))));
    }
    return null;
}
